#include <DHT.h>

#define DHTPIN 8         // DHT sensor connected to pin 8
#define DHTTYPE DHT11    // Define your DHT sensor type (DHT11, DHT22, etc.)
#define RED_LED    3        // Red LED connected to pin 3
#define YELLOW_LED 4
#define GREEN_LED  5 

DHT dht(DHTPIN, DHTTYPE);

void setup() {
  Serial.begin(9600);
  dht.begin();

  // Set LED pins as output
  pinMode(RED_LED, OUTPUT);
  pinMode(YELLOW_LED, OUTPUT);
  pinMode(GREEN_LED, OUTPUT);
}

void loop() {
  // Reading temperature and humidity from the DHT sensor
  float humidity;
  float temperature;
  int comfortLevel;

  humidity = dht.readHumidity();
  temperature = dht.readTemperature();

  // Determine comfort level
  comfortLevel = calculateComfortLevel(temperature, humidity);
                  
  // Print readings in the specified format for HTML parsing
  Serial.print("Temp: ");
  Serial.print(temperature);
  Serial.print(" Hum: ");
  Serial.print(humidity);
  Serial.print(" Comfort Level: ");
  Serial.println(comfortLevel);

  // Control LEDs based on comfort level
  if(comfortLevel <= 3 )
  {
      digitalWrite(RED_LED, HIGH);   
      digitalWrite(YELLOW_LED, LOW);   
      digitalWrite(GREEN_LED, LOW);
  }
  else if (comfortLevel <= 7)
  {
      digitalWrite(RED_LED, LOW);   
      digitalWrite(YELLOW_LED, HIGH);   
      digitalWrite(GREEN_LED, LOW);   
  }
  else
  {
      digitalWrite(RED_LED, LOW);   
      digitalWrite(YELLOW_LED, LOW);   
      digitalWrite(GREEN_LED, HIGH);   
  }
  
  
  delay(2000); // Wait for 2 seconds before next reading
}

// Function to calculate the comfort level based on temperature and humidity
int calculateComfortLevel(float temperature, float humidity) {
  if (temperature < 15 || temperature > 35 || humidity < 20 || humidity > 80) {
    return 1; // Extremely uncomfortable
  } else if ((temperature < 16 || temperature > 34) || (humidity < 25 || humidity > 75)) {
    return 2; // Very uncomfortable
  } else if ((temperature < 17 || temperature > 33) || (humidity < 30 || humidity > 70)) {
    return 3; // Uncomfortable
  } else if ((temperature < 18 || temperature > 32) || (humidity < 35 || humidity > 65)) {
    return 4; // Slightly uncomfortable
  } else if ((temperature < 19 || temperature > 31) || (humidity < 38 || humidity > 62)) {
    return 5; // Neutral
  } else if ((temperature >= 19 && temperature <= 31) && (humidity >= 40 && humidity <= 60)) {
    return 6; // Slightly comfortable
  } else if ((temperature >= 20 && temperature <= 30) && (humidity >= 42 && humidity <= 58)) {
    return 7; // Comfortable
  } else if ((temperature >= 21 && temperature <= 29) && (humidity >= 45 && humidity <= 55)) {
    return 8; // Very comfortable
  } else if ((temperature >= 22 && temperature <= 28) && (humidity >= 48 && humidity <= 52)) {
    return 9; // Optimal comfort
  } else if (temperature == 25 && humidity == 50) {
    return 10; // Perfect conditions
  }
  return 5; // Default neutral
}
